import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { SignupPageCmsService } from "./signup-page-cms.service";
import { UpdateSignupPageCmsDto } from "./dto/update-signup-page-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "signup-page-cms", version: Constants.API_VERSION_1 })

export class SignupPageCmsController {
    constructor(private readonly service: SignupPageCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "logo", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateSignupPageCmsDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI,
            logo: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
