// doSpacesService.ts
import { Inject, Injectable } from "@nestjs/common";
import * as AWS from "aws-sdk";
import { extname } from "path";
import { DoSpacesServiceLib, UploadedMulterFileI } from ".";
import { v4 as uuidv4 } from "uuid";
import axios from "axios";

// Typical nestJs service
@Injectable()
export class DoSpacesService {
    constructor(@Inject(DoSpacesServiceLib) private readonly s3: AWS.S3) {
    }

    async uploadFile(file: UploadedMulterFileI, uploadLocation?: string) {
        // Precaution to avoid having 2 files with the same name
        const extension = extname(file.originalname);
        let fileName = `disposhop.${uuidv4()}_do${extension}`;
        if (uploadLocation) {
            fileName = uploadLocation + fileName;
        }

        //const fileName = `${Date.now()}-${ file.originalname }`;

        // Return a promise that resolves only when the file upload is complete
        return new Promise((resolve, reject) => {
            this.s3.putObject(
                {
                    Bucket: "dispodutchie",
                    Key: fileName,
                    Body: file.buffer,
                    ACL: "public-read",
                    ContentType: file.mimetype
                },
                (error: AWS.AWSError) => {
                    if (!error) {
                        resolve(
                            `https://dispodutchie.nyc3.digitaloceanspaces.com/${fileName}`
                        );
                    } else {
                        reject(
                            new Error(
                                `DoSpacesService_ERROR: ${
                                    error.message || "Something went wrong"
                                }`
                            )
                        );
                    }
                }
            );
        });
    }

    async uploadImageFromURL(imageUrl: string, uploadLocation?: string) {
        const response: any = await axios.get(imageUrl, {
            responseType: "stream"
        });
        // console.log(response)
        if (response.status === 200) {
            // Precaution to avoid having 2 files with the same name
            const extension = ".png";
            let fileName = `disposhop.${uuidv4()}_do${extension}`;
            if (uploadLocation) {
                fileName = uploadLocation + fileName;
            }

            const uploadParams = {
                Bucket: "dispodutchie",
                Key: fileName,
                Body: response.data,
                ACL: "public-read" // Set the desired ACL for the uploaded image
            };

            const uploadResult = await this.s3.upload(uploadParams).promise();

            // Construct the image link based on your DigitalOcean Spaces configuration
            return `https://dispodutchie.nyc3.digitaloceanspaces.com/${fileName}`;
        }
    }
}
