import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { BlogCategoryRepository } from "./blog-category.repository";
import { CreateBlogCategoryDto } from "./dto/create-blog-category.dto";
import { UpdateBlogCategoryDto } from "./dto/update-blog-category.dto";
import { BlogCategory } from "./entities/blog-category.entity";

@Injectable()
export class BlogCategoryService {
    constructor(
        @InjectRepository(BlogCategoryRepository)
        private readonly repository: BlogCategoryRepository
    ) {
    }

    async create(dto: CreateBlogCategoryDto): Promise<BlogCategory | Error> {
        const res: any = await this.repository.findCategoryByCategoryName(dto.categoryName);
        if (res.length > 0) {
            throw new HttpException(
                "Category name already exists.",
                HttpStatus.BAD_REQUEST
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Blog category created successfully", "data", data);
    }

    async findAll(): Promise<BlogCategory[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog category fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateBlogCategoryDto): Promise<BlogCategory | Error> {
        const category: any = await this.repository.findOneEntity(id);
        if (!category) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog category updated successfully", "data", data);
    }

    async findOne(id: string): Promise<BlogCategory[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog category fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Blog category deleted successfully");
    }
}
