import { Body, Controller, Delete, Get, Param, Patch, Post, Query, UseGuards } from "@nestjs/common";
import { ProductServiceService } from "./product-service.service";
import { CreateProductServiceDto } from "./dto/create-product-service.dto";
import { UpdateProductServiceDto } from "./dto/update-product-service.dto";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { SearchProductServiceDto } from "./dto/search-product-service.dto";

@Controller({ path: "product-service", version: Constants.API_VERSION_1 })
export class ProductServiceController {
    constructor(private readonly service: ProductServiceService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateProductServiceDto) {
        return this.service.create(dto);
    }

    @Get("/synchronize")
    // @UseGuards(AdminAuthGuard)
    productSynchronize() {
        return this.service.productSynchronize();
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":slug")
    // @UseGuards(AdminAuthGuard)
    findOne(@Param("slug") slug: string, @Query('retailerId') retailerId: string) {
        return this.service.findOne(slug, retailerId);
    }

    @Patch(":id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateProductServiceDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    remove(@Param("id") id: string) {
        return this.service.remove(id);
    }

    //#region Elastic Search

    @Get("/populate/elasticsearch")
    @UseGuards(AdminAuthGuard)
    async productPopulateElasticsearch() {
        let index: any;
        if (process.env.ENVIRONMENT == "local") {
            index = process.env.PRODUCT_INDEX_DEV;
        } else {
            index = process.env.PRODUCT_INDEX_PROD;
        }
        return await this.service.indexBulkData(index);
    }


    @Post("/elastic/search")
    async productElasticsearch(@Body() searchProductServiceDto: SearchProductServiceDto) {
        let index: any;
        if (process.env.ENVIRONMENT == "local") {
            index = process.env.PRODUCT_INDEX_DEV;
        } else {
            index = process.env.PRODUCT_INDEX_PROD;
        }
        return await this.service.search(index, searchProductServiceDto);
    }

    @Post("/elastic/search/details")
    async productElasticsearchDetails(@Body() searchProductServiceDto: SearchProductServiceDto) {
        let index: any;
        if (process.env.ENVIRONMENT == "local") {
            index = process.env.PRODUCT_INDEX_DEV;
        } else {
            index = process.env.PRODUCT_INDEX_PROD;
        }
        return await this.service.searchDetails(index, searchProductServiceDto);
    }

    //#endregion Elastic Search
}
